<?php

// phpcs:disable Yoast.NamingConventions.NamespaceName.TooLong -- Needed in the folder structure.
namespace Yoast\WP\SEO\Dashboard\Infrastructure\Endpoints;

use Yoast\WP\SEO\Routes\Endpoint\Endpoint_Interface;

interface Dashboard_Endpoint_Interface extends Endpoint_Interface {}
