<?php

// phpcs:disable Yoast.NamingConventions.NamespaceName.TooLong -- Needed in the folder structure.
namespace Yoast\WP\SEO\Llms_Txt\Domain\Content;

/**
 * Describes the post collection interface.
 */
interface Post_Collection_Interface {}
