<?php

/**
 *
 * @package Duplicator/Installer
 */

defined('ABSPATH') || defined('DUPXABSPATH') || exit;

?>
<p>
    <b>Import:</b> Adds all users from the source site to the target site. Does not remove or alter existing target users.
</p>
<p>
    <b>Ignore:</b> Don't import users from the source site.
    All content on the source site will be assigned to the <u>content author</u> selected user.
</p>