#ai-data {
  font-family: "2.8.18"; /* Used for version number of the file */
}

#blocked-warning {
  display: none;
}

/*:focus {*/
/*  outline: #444 auto 1px;*/
/*}*/

hr {
  border: 0;
  border-top: 1px solid #ddd;
  border-bottom: 1px solid #fafafa;
  display: block;
  unicode-bidi: isolate;
  margin: 0.5em 0;
  overflow: hidden;
}

.ui-widget, .ai-form td {
  font-family: Arial,Verdana,sans-serif;
  font-size: 12px!important;
}

.ai-form .ui-widget {
    position: relative;
}

.ui-widget input, .ui-widget select, .ui-widget textarea, .ui-widget button {
   font-family: sans-serif,Arial,Verdana;
   font-size: 12px;
}

.ui-widget-header {
  border: 1px solid #aaa !important;
  background: #ccc url(images/ui-bg_highlight-soft_75_cccccc_1x100.png) 50% 50% repeat-x !important;
}

.ui-state-active, .ui-widget-content .ui-state-active, .ui-widget-header .ui-state-active {
  background: #fff url(images/ui-bg_glass_65_ffffff_1x400.png) 50% 50% repeat-x !important;
}

.ui-state-default, .ui-widget-content .ui-state-default, .ui-widget-header .ui-state-default {
  font-weight: normal;
  color: #555;
}

.ui-state-default a, .ui-state-default a:link, .ui-state-default a:visited {
  color: #555;
  text-decoration: none;
}

.ui-state-highlight {
  background: #ff4;
}

.ui-widget-overlay {
  background: #000;
  opacity: 0.5;
  filter: alpha(opacity=50);
}

/*.ui-button.ui-corner-all.ui-widget {*/
.ui-button.ui-corner-all.ui-widget:not(.ai-button-small), button.ai-button, button.ai-button2, input[type=submit] {
  padding: .4em 1em !important;
  border: 1px solid #d3d3d3;
  border-radius: 4px;
  background: #e6e6e6 url(images/ui-bg_glass_75_e6e6e6_1x400.png) 50% 50% repeat-x;
  color: #666;
  cursor: pointer;
}

input.ai-button-exception.ui-button.ui-corner-all.ui-widget[type=submit] {
  padding: 1px 3px !important;
}

/*.ai-button.ui-button.ui-corner-all.ui-widget {*/
/*.ai-button.ai-button-small.ui-button.ui-corner-all.ui-widget {*/
.ai-button.ai-button-small {
  padding: 0 !important;
  border-radius: 4px;
  cursor: pointer;
}

button.ui-button.ui-corner-all.ui-dialog-titlebar-close {
  display: none;
}

button.ai-top-button {
  min-width: 50px;
}

.ui-button-text-only .ui-button-text {
  padding: 0;
}

.adsense-list .ui-button-text, .select-image .ui-button-text, iab-ads-txt .ui-button-text {
  padding: 0.4em 0.5em;
}

.ace_editor {
  border: 1px solid #ddd;
  border-radius: 4px;
}

.ai-icon-gear {
  width:  16px;
  height: 16px;
  background: url('images/icons.png') 0 -40px;
  background-repeat: no-repeat;
}

.ai-icon-gear.on {
  background: url('images/icons.png') -20px -40px;
}

.ai-icon-gear.red {
  background: url('images/icons.png') -60px -40px;
}

a.simple-link {
  text-decoration: none;
  box-shadow: 0 0 0;
  color: #0073aa;
}

a.clear-link, a.clear-link:hover, a.clear-link:focus {
  color: transparent;
  text-decoration: none;
  box-shadow: 0 0 0;
}

.ai-rounded {
  border-radius: 5px;
}

.ai-form.ai-rounded input, .ai-form.ai-rounded select {
  border-radius: 5px;
}

.ai-form.ai-rounded input[type=submit], .ai-button.ui-button.ui-corner-all.ui-widget {
  border: 1px solid #d3d3d3;
  background: #e6e6e6 url(images/ui-bg_glass_75_e6e6e6_1x400.png) 50% 50% repeat-x;
}

#ai-form div.ai-rounded, #ai-sidebar div.ai-rounded {
  margin: 8px 0;
  padding: 8px;
  border: 1px solid rgb(221, 221, 221);
  border-radius: 5px;
}

.ai-settings-table {
  border-spacing: 2px;
}

.ai-settings-table.left {
  float: left;
  width: 70%
}

.ai-settings-table.left td.label {
  max-width: 104px;
}

.ai-settings-table.right {
  float: right;
  width: 30%
}

.ai-settings-table.ai-values td:first-child {
  width: 35%;
}

.ai-settings-table.fixed {
  table-layout: fixed;
}

/*#editor-1 {*/
/*  font-family: Courier, 'Courier New', monospace, tahoma;*/
/*  font-family: tahoma;*/
/*  font-size: 10px";*/
/*}*/

.nav-tab {
  border-top-left-radius: 5px;
  border-top-right-radius: 5px;
}
.nav-tab-active, .nav-tab-active:hover {
  background: #fff;
}

.exceptions a {
  text-decoration: none;
}
.exceptions th.page-title {
  text-align: left;
}
.exceptions tr.even {
  background: #f0f0f0;
}
.exceptions td.page-title {
  padding-right: 20px;
}
.exceptions th.id, .exceptions td.id {
  padding-right: 10px;
  text-align: right;
}
.exceptions th.type, .exceptions td.type {
  min-width: 60px;
  padding-right: 10px;
  text-align: left;
}
.exceptions th.page-title, .exceptions td.page-title {
  width: 90%;
  overflow: hidden;
  max-width: 150px;
}
.exceptions th.page-only, .exceptions td.page-only {
  padding-right: 10px;
  width: 100%;
}
.exceptions th.block, .exceptions td.block {
  text-align: center;
  min-width: 22px;
  cursor: pointer;
}
.exceptions td.button-delete {
  cursor: pointer;
}
.ai-small-button .ui-button-text-only .ui-button-text {
   padding: 0px;
}
.ai-responsive-table td {
  white-space: nowrap;
  padding: 0;
}

.no-select {
  -webkit-user-select: none;  /* Chrome all / Safari all */
  -moz-user-select: none;     /* Firefox all */
  -ms-user-select: none;      /* IE 10+ */
  user-select: none;
}
.select {
  -webkit-user-select: text;
  -moz-user-select: text;
  -ms-user-select: text;
  user-select: text;
}
.copy-blocker {
   position: absolute;
   user-select: text;
   height: 1%;
}

.ui-dialog {
  z-index: 10000 !important;
}
.ui-dialog .ui-dialog-titlebar-close {
  outline: none;
}
.no-title .ui-dialog-titlebar {
  display:none
}

.ai-form {
  width: 735px;
}

.ui-datepicker {
  z-index: 202!important;
}

div.ai-chart-container {
  position: relative;
  margin: 8px 0;
}

div.ai-chart-container.versions {
  display: inline-block;
  margin: 20px 20px 0;
}

div.ai-chart {
  width: 735px;
  height: 140px;
}

div.versions div.ai-chart {
  width: 200px;
  height: 140px;
}

div.legend div.ai-chart {
  height: 25px;
}

div.ai-chart-label {
  position: absolute;
  top: 13px;
  left: 44px;
  z-index: 202;
  opacity: 0.5;
  display: none;
}

div.ai-chart-version-label {
  position: absolute;
  top: 13px;
  right: 44px;
  z-index: 202;
  opacity: 0.5;
  cursor: pointer;
  display: none;
}

.ai-label-index {
  cursor: pointer;
}

div.ai-chart-container.versions div.ai-chart-label {
  z-index: 1;
}

div.versions div.ai-chart-label {
  top: -16px;
  left: 80px;
}

.legend div.ai-chart-label {
  top: 34px;
}

div.ai-tooltip {
  z-index: 203;
}

div.ai-tooltip .version {
  font-weight: bold;
}

.ai-statistics-export-data {
  display: none;
}

#ai-settings {
  box-sizing: content-box;
  margin-right: 24px;
}

#ai-settings-wrapper.settings-hidden {
  width: 740px;
}

#ai-settings-wrapper.settings-hidden #ai-container {
  display: none;
}

.ui-tabs .ui-tabs-nav li {
  margin: 1px 0.17em 0 0;
}

#ai-tabs a {
  width: 14px;
  text-align: center;
  font-size: 12px;
  font-weight: normal;
  color: #555;
}

#ai-tabs {
  padding: .2em 0 0 .6em;
}

#ai-scroll-tabs {
  height: 42px;
}

#ai-plugin-settings-tabs li a, #ai-general-plugin-settings-tabs li a {
  padding: .5em 0.4em;
  font-size: 11.4px;
}

#block-ranges {
  display: none;
  margin: 2px 0 0 2px;
}

#header-buttons {
  min-height: 26px;
  margin: 2px 0;
  float: right;
}

#header-buttons .checkbox-button {
  margin-left: 5px;
}
.max-input {
  display: table;
  width: 100%;
}

.simple-editor {
  width: 733px;
  min-width: 370px;
  height: 386px;
}

textarea.simple-editor {
  height: 388px;
}

.simple-editor.small {
  height: 190px;
}

textarea.simple-editor.small {
  height: 192px;
}

.ms-container {
  width: 100%;
  font-size: 12px;
}

.ms-container .ms-selectable, .ms-container .ms-selection {
  width: 47%;
  max-width: 340px;
}

.ms-container .ms-selectable li.ms-elem-selectable, .ms-container .ms-selection li.ms-elem-selection {
  padding: 1px 10px;
  font-size: 12px;
}

.ms-container dd, .ms-container li {
/*.ms-container dd, li {*/
  margin-bottom: 4px;
}

.feature-list li, .ai-help li {
  margin-bottom: 2px;
}

.ms-container .search-input {
  width: 100%;
  border-radius: 4px;
}

.ms-container div.ms-selection {
  margin-top: 24px;
}

div.custom-range-controls {
  width: fit-content;
  width: -moz-fit-content;
}

div.custom-range-controls .ai-toolbar-button {
 padding: 0 0 0 8px;
}

div.custom-range-controls .selected, .ai-date-input .selected {
  color: #33d;
}

input.ai-date-input {
  width: 85px;
}

input.ai-date-input::-webkit-input-placeholder { /* Edge */
  color: #ccc;
}

input.ai-date-input:-ms-input-placeholder { /* Internet Explorer 10-11 */
  color: #ccc;
}

input.ai-date-input::placeholder {
  color: #ccc;
}

.country-flags .ms-container .ms-selectable li.flag-icon.ms-elem-selectable, .country-flags .ms-container .ms-selection li.flag-icon.ms-elem-selection {
  padding-left: 30px;
}

.ai-list-filter-container {
  display: none;
}

.ai-list-filter-container .filter-input {
  width: 100px;
}

.ai-list-filter-container .filter-message {
  vertical-align: middle;
  padding-left: 5px;
}


.flag-icon {
  display: list-item;
  width: auto;
  line-height: inherit;
}

.flag-icon, .flag-icon-background {
  background-position: initial;
}

.flag-icon.inline {
  display: inline-block;
  width: 20px;
  margin-right: 10px;
}

div.automatic-insertion {
  width: 56px;
  height: 56px;
}

ul.thumbnails.image_picker_selector li {
  margin: 0px 5px 4px 0px;
  cursor: pointer;
}

ul.thumbnails.image_picker_selector li .thumbnail {
  padding: 4px;
}

ul.thumbnails.image_picker_selector li .thumbnail.selected {
  background: #666;
}
li.automatic-insertion p {
  width: 57px;
  font-size: inherit;
  margin: 4px 0;
}

div.automatic-insertion img {
  width: 56px;
  height: 56px;
}

.ai-toolbar-button {
  display: table-cell;
  vertical-align: top;
  width: 28px;
  padding: 0 0 0 10px;
}

.checkbox-button.dashicons {
  width: 28px;
  height: 26px;
  line-height: 20px;
  font-family: dashicons;
  color: #ababab;
  vertical-align: top;
}

.checkbox-list-button.dashicons {
  width: 20px;
  height: 22px;
  line-height: 20px;
  padding: 0;
  background: #fff;
  color: #333;
  border: 0;
}

table.ai-lists td {
  padding: 1px 0;
}

table.ai-images td {
  padding: 2px 0;
}

table.ai-lists .ai-button, table.ai-images .ai-button {
  display: none;
  outline: transparent;
  float: right;
  margin: 1px 3px 0 5px;
  width: 15px;
  height: 15px;
}

.checkbox-button.dashicons.on {
  color: #5f76ff;
}

/*.checkbox-button.dashicons.on {*/
/*  color: red;*/
/*}*/

.checkbox-button.dashicons.green {
  color: #0d0;
}

.checkbox-button.dashicons.blue {
  color: #7373ff;
}

tr.ai-website-list .ai-website-key {
  color: #888;
}

tr.ai-website-list.read-only .ai-website-key {
  color: #49b3ff;
}

/*.checkbox-button.dashicons.blue-active {*/
/*  color: #66f;*/
/*}*/

.checkbox-button.dashicons.red {
  color: #f00;
}

.checkbox-button.dashicons.violet {
  color: #90f;
}

.checkbox-button.dashicons.light-blue {
  color: #b0d2fd;
}

.checkbox-button.dashicons.light-red {
  color: #ff8585;
}


#ai-blocked-ip-addresses-list {
  text-align: left;
}

#ai-blocked-ip-addresses-list .cfp-delete {
  text-align: right;
}

#ai-blocked-ip-addresses-list td.cfp-delete {
  cursor: pointer;
}

#ai-blocked-ip-addresses-list .even {
  background: #f8f8f8
}

#ai-blocked-ip-addresses-list .odd {
  background: #fff
}



.ai-public-controls {
   color: #ddd;
 }

.ai-public-controls.on {
   color: #f33;
 }

.ai-list-button {
  display: table-cell;
/*  margin-right: 2px;*/
  width: 20px;
}

.ai-toolbar-button.text {
  width: auto;
}

.ai-toolbar-button.small {
  width: 20px;
}

.ai-toolbar-button.ai-button-left {
  padding: 0 10px 0 0;
}

.checkbox-button {
   background-image: none, linear-gradient(to bottom, #f6f6f6 0, #eaeaea 100%);
   background-position: 50% 50%;
   background-color: #e3e3e3;
   border: solid 1px lightgrey;
   border-radius: 4px;
   -webkit-border-radius: 4px;
   -moz-border-radius: 4px;
   cursor: pointer;
   padding: 2px 3px;
   display: inline-block;
   margin: 0;
   font-family: inherit;
   line-height: 1.66em;
   text-align: center;
   text-decoration: none;
   -webkit-box-sizing: border-box;
   -moz-box-sizing: border-box;
   box-sizing: border-box;
}

.custom-range-controls .checkbox-button {
  border-radius: 3px;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
}

.ai-list-button .checkbox-button {
  padding: 2px 2px;
  margin: 1px 0 1px;
  border-radius: 3px;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
}

.text .checkbox-button {
  font-size: 11px;
  padding: 0px 5px 0px 4px;
  margin-top: 2px;
}

.ai-bw {
  -webkit-filter: grayscale(100%); /* Safari 6.0 - 9.0 */
  filter: grayscale(100%);
}

.checkbox-icon {
   background-position: center;
   display: inline-block;
   float: left;
   width: 20px;
   height: 20px;
   overflow: hidden;
   background-repeat: no-repeat;
   font-size: 0;
   line-height: 0;
   text-indent: -3333px;
   text-align: center;
   vertical-align: middle;
}

.ai-colorpicker-alpha {
  background-image: url("images/transparency-24.png");
}


/* To overeride [class*=" icon-"], [class^=icon-] */
span.checkbox-icon {
   width: 20px;
   height: 20px;
}

.checkbox-icon.image {
  width: 22px;
  height: 20px;
}

.checkbox-icon.size-16 {
  width: 16px;
  height: 16px;
}

.checkbox-icon.size-img16 {
  width: 16px;
  height:16px;
/*  background-size: 16px 16px;*/
}

.checkbox-icon.size-16w {
  width: 17px;
  height: 16px;
}

.checkbox-icon.size-12 {
  width: 12px;
  height: 12px;
  margin: 3px 0;
}

.checkbox-icon.size-8 {
  width: 8px;
  height: 8px;
}

.checkbox-icon.size-8.icon-text {
  font-size: 9px;
  line-height: 9px;
  text-indent: 0;
  color: #ccc;
}

.checkbox-icon.icon-none {
  width: 10px;
  height: 12px;
  margin-top: 6px;
}

.list-button.lb-size-16 {
  width: 16px;
  height: 16px;
}

.list-button {
  margin: 0;
  background-image: url(images/ui-icons_888888_256x240.png)
}

img.automatic-insertion.im-disabled {
  background: url('images/insertions-alignmets.png') 0 0;
}

img.automatic-insertion.im-before-post {
  background: url('images/insertions-alignmets.png') -56px 0;
}

img.automatic-insertion.im-after-post {
  background: url('images/insertions-alignmets.png') -112px 0;
}

img.automatic-insertion.im-before-content {
  background: url('images/insertions-alignmets.png') -168px 0;
}

img.automatic-insertion.im-after-content {
  background: url('images/insertions-alignmets.png') -224px 0;
}

img.automatic-insertion.im-before-paragraph {
  background: url('images/insertions-alignmets.png') -280px 0;
}

img.automatic-insertion.im-after-paragraph {
  background: url('images/insertions-alignmets.png') -336px 0;
}

img.automatic-insertion.im-before-excerpts {
  background: url('images/insertions-alignmets.png') -392px 0;
}

img.automatic-insertion.im-after-excerpts {
  background: url('images/insertions-alignmets.png') 0 -56px;
}

img.automatic-insertion.im-between-posts {
  background: url('images/insertions-alignmets.png') -56px -56px;
}

img.automatic-insertion.im-before-comments {
  background: url('images/insertions-alignmets.png') -112px -56px;
}

img.automatic-insertion.im-between-comments {
  background: url('images/insertions-alignmets.png') -168px -56px;
}

img.automatic-insertion.im-after-comments {
  background: url('images/insertions-alignmets.png') -224px -56px;
}

img.automatic-insertion.im-footer {
  background: url('images/insertions-alignmets.png') -280px -56px;
}

img.automatic-insertion.im-custom-hook {
  background: url('images/insertions-alignmets.png') -336px -56px;
}

img.automatic-insertion.im-no-wrapping {
  background: url('images/insertions-alignmets.png') -392px -56px;
}

img.automatic-insertion.im-custom-css {
  background: url('images/insertions-alignmets.png') 0 -112px;
}

img.automatic-insertion.im-default {
  background: url('images/insertions-alignmets.png') -56px -112px;
}

img.automatic-insertion.im-align-left {
  background: url('images/insertions-alignmets.png') -112px -112px;
}

img.automatic-insertion.im-center {
  background: url('images/insertions-alignmets.png') -168px -112px;
}

img.automatic-insertion.im-align-right {
  background: url('images/insertions-alignmets.png') -224px -112px;
}

img.automatic-insertion.im-float-left {
  background: url('images/insertions-alignmets.png') -280px -112px;
}

img.automatic-insertion.im-float-right {
  background: url('images/insertions-alignmets.png') -336px -112px;
}

img.automatic-insertion.im-sticky-left {
  background: url('images/insertions-alignmets.png') -392px -112px;
}

img.automatic-insertion.im-sticky-right {
  background: url('images/insertions-alignmets.png') 0 -168px;
}

img.automatic-insertion.im-sticky-top {
  background: url('images/insertions-alignmets.png') -56px -168px;
}

img.automatic-insertion.im-sticky-bottom {
  background: url('images/insertions-alignmets.png') -112px -168px;
}

img.automatic-insertion.im-above-header {
  background: url('images/insertions-alignmets.png') -168px -168px;
}

img.automatic-insertion.im-before-html {
  background: url('images/insertions-alignmets.png') -224px -168px;
}

img.automatic-insertion.im-after-html {
  background: url('images/insertions-alignmets.png') -280px -168px;
}

img.automatic-insertion.im-sticky-content-left {
  background: url('images/insertions-alignmets.png') -336px -168px;
}

img.automatic-insertion.im-sticky-content-right {
  background: url('images/insertions-alignmets.png') -392px -168px;
}

img.automatic-insertion.im-sticky-center-horizontal {
  background: url('images/insertions-alignmets.png') 0 -224px;
}

img.automatic-insertion.im-sticky-center-vertical {
  background: url('images/insertions-alignmets.png') -56px -224px;
}

img.automatic-insertion.im-sticky-scroll {
  background: url('images/insertions-alignmets.png') -112px -224px;
}

img.automatic-insertion.im-sticky {
  background: url('images/insertions-alignmets.png') -168px -224px;
}

img.automatic-insertion.im-close-top-left {
  background: url('images/insertions-alignmets.png') -224px -224px;
}

img.automatic-insertion.im-close-top-right {
  background: url('images/insertions-alignmets.png') -280px -224px;
}

img.automatic-insertion.im-close-bottom-right {
  background: url('images/insertions-alignmets.png') -336px -224px;
}

img.automatic-insertion.im-close-bottom-left {
  background: url('images/insertions-alignmets.png') -392px -224px;
}

img.automatic-insertion.im-close-none {
  background: url('images/insertions-alignmets.png') -0px   -280px;
}

img.automatic-insertion.im-inside-html {
  background: url('images/insertions-alignmets.png') -56px  -280px;
}

img.automatic-insertion.im-before-image {
  background: url('images/insertions-alignmets.png') -112px -280px;
}

img.automatic-insertion.im-after-image {
  background: url('images/insertions-alignmets.png') -168px -280px;
}



.ai-background img.automatic-insertion.im-sticky-left {
  background: url('images/insertions-alignmets.png') -224px -280px;
}

.ai-background img.automatic-insertion.im-sticky-content-left {
  background: url('images/insertions-alignmets.png') -336px -280px;
}

.ai-background img.automatic-insertion.im-sticky-right {
  background: url('images/insertions-alignmets.png') -280px -280px;
}

.ai-background img.automatic-insertion.im-sticky-content-right {
  background: url('images/insertions-alignmets.png') -392px -280px;
}

.ai-background img.automatic-insertion.im-sticky-center-horizontal {
  background: url('images/insertions-alignmets.png') 0 -336px;
}


img.automatic-insertion {
  background-size: 448px!important;
}


img.automatic-insertion.preview.im-no-wrapping {
  background: url('images/insertions-alignmets.png') -350px -50px;
}

img.automatic-insertion.preview.im-custom-css {
  background: url('images/insertions-alignmets.png') 0 -100px;
}

img.automatic-insertion.preview.im-default {
  background: url('images/insertions-alignmets.png') -50px -100px;
}

img.automatic-insertion.preview.im-align-left {
  background: url('images/insertions-alignmets.png') -100px -100px;
}

img.automatic-insertion.preview.im-center {
  background: url('images/insertions-alignmets.png') -150px -100px;
}

img.automatic-insertion.preview.im-align-right {
  background: url('images/insertions-alignmets.png') -200px -100px;
}

img.automatic-insertion.preview.im-float-left {
  background: url('images/insertions-alignmets.png') -250px -100px;
}

img.automatic-insertion.preview.im-float-right {
  background: url('images/insertions-alignmets.png') -300px -100px;
}

img.automatic-insertion.preview.im-sticky-left {
  background: url('images/insertions-alignmets.png') -350px -100px;
}

img.automatic-insertion.preview.im-sticky-right {
  background: url('images/insertions-alignmets.png') 0 -150px;
}

img.automatic-insertion.preview.im-sticky-top {
  background: url('images/insertions-alignmets.png') -50px -150px;
}

img.automatic-insertion.preview.im-sticky-bottom {
  background: url('images/insertions-alignmets.png') -100px -150px;
}

img.automatic-insertion.preview.im-sticky-content-left {
  background: url('images/insertions-alignmets.png') -300px -150px;
}

img.automatic-insertion.preview.im-sticky-content-right {
  background: url('images/insertions-alignmets.png') -350px -150px;
}

img.automatic-insertion.preview.im-sticky-content-right {
  background: url('images/insertions-alignmets.png') -350px -150px;
}

img.automatic-insertion.preview.im-sticky-center-horizontal {
  background: url('images/insertions-alignmets.png') 0 -200px;
}

img.automatic-insertion.preview.im-sticky-center-vertical {
  background: url('images/insertions-alignmets.png') -50px -200px;
}

img.automatic-insertion.preview.im-sticky-scroll {
  background: url('images/insertions-alignmets.png') -100px -200px;
}

img.automatic-insertion.preview.im-sticky {
  background: url('images/insertions-alignmets.png') -150px -200px;
}

img.automatic-insertion.preview.im-close-top-left {
  background: url('images/insertions-alignmets.png') -200px -200px;
}

img.automatic-insertion.preview.im-close-top-right {
  background: url('images/insertions-alignmets.png') -250px -200px;
}

img.automatic-insertion.preview.im-close-bottom-right {
  background: url('images/insertions-alignmets.png') -300px -200px;
}

img.automatic-insertion.preview.im-close-bottom-left {
  background: url('images/insertions-alignmets.png') -350px -200px;
}

img.automatic-insertion.preview.im-close-none {
  background: url('images/insertions-alignmets.png') -0px   -250px;
}

img.automatic-insertion.preview.im-before-image {
  background: url('images/insertions-alignmets.png') -100px   -250px;
}

img.automatic-insertion.preview.im-after-image {
  background: url('images/insertions-alignmets.png') -150px  -250px;
}


.ai-background img.automatic-insertion.preview.im-sticky-left {
  background: url('images/insertions-alignmets.png') -200px -250px;
}

.ai-background img.automatic-insertion.preview.im-sticky-content-left {
  background: url('images/insertions-alignmets.png') -300px -250px;
}

.ai-background img.automatic-insertion.preview.im-sticky-right {
  background: url('images/insertions-alignmets.png') -250px -250px;
}

.ai-background img.automatic-insertion.preview.im-sticky-content-right {
  background: url('images/insertions-alignmets.png') -350px -250px;
}

.ai-background img.automatic-insertion.preview.im-sticky-center-horizontal {
  background: url('images/insertions-alignmets.png') 0 -300px;
}


img.automatic-insertion.preview {
  background-size: 400px!important;
}


.checkbox-icon.icon-tracking {
  background: url('images/icons.png') -40px -20px;
}

.checkbox-icon.icon-tracking.on {
  background: url('images/icons.png') -40px 0;
}

.tracking-disabled .checkbox-icon.icon-tracking.on {
  background: url('images/icons.png') -40px -40px;
}

.checkbox-icon.icon-tablet {
  background: url('images/icons.png') -20px -20px;
}

.checkbox-icon.icon-tablet.on {
  background: url('images/icons.png') -20px 0;
}

.checkbox-icon.icon-php {
  background: url('images/icons.png') 0 -20px;
}

.checkbox-icon.icon-php.on {
  background: url('images/icons.png') 0 0;
}

.checkbox-icon.icon-enabled {
  background: url('images/icons.png') -100px -20px;
}

.checkbox-icon.icon-enabled.on {
  background: url('images/icons.png') -100px 0;
}

.checkbox-icon.icon-export-import {
  background: url('images/icons.png') -80px -20px;
}

.checkbox-icon.icon-export-import.on {
  background: url('images/icons.png') -80px 0;
}

.checkbox-icon.icon-statistics {
  background: url('images/icons.png') -60px -20px;
}

.checkbox-icon.icon-statistics.on {
  background: url('images/icons.png') -60px 0;
}

.checkbox-icon.icon-adb {
  background: url('images/icons.png') -120px -20px;
}

.checkbox-icon.icon-adb.on {
  background: url('images/icons.png') -120px 0;
}

.checkbox-icon.icon-code {
  background: url('images/icons.png') 0 -80px;
}

.checkbox-icon.icon-code.on {
  background: url('images/icons.png') 0 -60px;
}

.checkbox-icon.icon-rotation {
  background: url('images/icons.png') -20px -80px;
}

.checkbox-icon.icon-rotation.on {
  background: url('images/icons.png') -20px -60px;
}

.checkbox-icon.icon-rotation.active {
  background: url('images/icons.png') -100px -40px;
}

.checkbox-icon.icon-generate {
  background: url('images/icons.png') -40px -80px;
}

.checkbox-icon.icon-generate.on {
  background: url('images/icons.png') -40px -60px;
}

.checkbox-icon.icon-import {
  background: url('images/icons.png') -60px -80px;
}

.checkbox-icon.icon-import.on {
  background: url('images/icons.png') -60px -60px;
}

.checkbox-icon.icon-edit {
  background: url('images/icons.png') -80px -40px;
}

.checkbox-icon.icon-minus {
  background: url('images/icons.png') -80px -80px;
}

.checkbox-icon.icon-plus {
  background: url('images/icons.png') -80px -60px;
}

.checkbox-icon.icon-tools {
  background: url('images/icons.png') -100px -80px;
}

.checkbox-icon.icon-tools.on {
  background: url('images/icons.png') -100px -60px;
}

.checkbox-icon.icon-copy {
  background: url('images/icons.png') -120px -80px;
}

.checkbox-icon.icon-copy.on {
  background: url('images/icons.png') -120px -60px;
}

.checkbox-icon.icon-paste {
  background: url('images/icons.png') -120px -40px;
}

.checkbox-icon.icon-paste-name {
  background: url('images/icons.png') -180px -40px;
}

.checkbox-icon.icon-paste-code {
  background: url('images/icons.png') -160px -40px;
}

.checkbox-icon.icon-paste-settings {
  background: url('images/icons.png') -140px -40px;
}

.checkbox-icon.icon-clear {
  background: url('images/icons.png') -160px -80px;
}

.checkbox-icon.icon-pause {
  background: url('images/icons.png') -180px -80px;
}

.checkbox-icon.icon-pause.on {
  background: url('images/icons.png') -180px -60px;
}

.checkbox-icon.icon-ads-txt {
  background: url('images/icons.png') -160px -60px;
  -webkit-filter: grayscale(100%); /* Safari 6.0 - 9.0 */
  filter: grayscale(100%);
}
.checkbox-icon.icon-ads-txt.on {
   -webkit-filter: unset;
  filter: unset;
}


.checkbox-icon.icon-enabled-all {
  background: url('images/icons.png') -142px -22px;
}

.checkbox-icon.icon-enabled-all.on {
  background: url('images/icons.png') -142px -2px;
}


.checkbox-icon.icon-rearrange {
  background: url('images/icons.png') -140px -80px;
}

.checkbox-icon.icon-rearrange.on {
  background: url('images/icons.png') -140px -60px;
}

.checkbox-icon.icon-loading {
  background: url('images/icons.png') -163px -23px;
}

.checkbox-icon.icon-loading.on {
  background: url('images/icons.png') -163px -3px;
}

.checkbox-icon.icon-reload {
  background: url('images/icons.png') -161px -22px;
}

.checkbox-icon.icon-reload.on {
  background: url('images/icons.png') -161px -2px;
}

.checkbox-icon.icon-auto-refresh {
  background: url('images/icons.png') -180px -20px;
}

.checkbox-icon.icon-auto-refresh.on {
  background: url('images/icons.png') -180px 0;
}

.checkbox-icon.icon-css {
  background: url('images/icons.png') 0 -100px;
  -webkit-filter: grayscale(100%); /* Safari 6.0 - 9.0 */
  filter: grayscale(100%);
  opacity: 0.5;
}

.checkbox-icon.icon-css.on {
  -webkit-filter: unset;
  filter: unset;
  opacity: unset;
}

.checkbox-icon.icon-js {
  background: url('images/icons.png') -20px -100px;
  -webkit-filter: grayscale(100%); /* Safari 6.0 - 9.0 */
  filter: grayscale(100%);
  opacity: 0.5;
}

.checkbox-icon.icon-js.on {
  -webkit-filter: unset;
  filter: unset;
  opacity: unset;
}

.checkbox-icon.icon-php-red {
  background: url('images/icons.png') -40px -100px;
  -webkit-filter: grayscale(100%); /* Safari 6.0 - 9.0 */
  filter: grayscale(100%);
  opacity: 0.5;
}

.checkbox-icon.icon-php-red.on {
  -webkit-filter: unset;
  filter: unset;
  opacity: unset;
}

.checkbox-icon.icon-h {
  background: url('images/icons.png') -60px -100px;
  -webkit-filter: grayscale(100%); /* Safari 6.0 - 9.0 */
  filter: grayscale(100%);
  opacity: 0.5;
}

.checkbox-icon.icon-h.on {
  -webkit-filter: unset;
  filter: unset;
  opacity: unset;
}

.checkbox-icon.icon-f {
  background: url('images/icons.png') -80px -100px;
  -webkit-filter: grayscale(100%); /* Safari 6.0 - 9.0 */
  filter: grayscale(100%);
  opacity: 0.5;
}

.checkbox-icon.icon-f.on {
  -webkit-filter: unset;
  filter: unset;
  opacity: unset;
}

.checkbox-icon.icon-html {
  background: url('images/icons.png') -100px -100px;
  -webkit-filter: grayscale(100%); /* Safari 6.0 - 9.0 */
  filter: grayscale(100%);
  opacity: 0.5;
}

.checkbox-icon.icon-html.on {
  -webkit-filter: unset;
  filter: unset;
  opacity: unset;
}

.checkbox-icon.icon-adsense {
  background: url('images/icons.png') -120px -100px;
  -webkit-filter: grayscale(100%); /* Safari 6.0 - 9.0 */
  filter: grayscale(100%);
}

.checkbox-icon.icon-adsense.on {
   -webkit-filter: unset;
  filter: unset;
}


.checkbox-icon.size-8.icon-stop {
  background: #ddd;
}

.checkbox-icon.size-8.icon-preview {
  width: 0;
  height: 0;
  margin-left: 1px;
  border-top: 4px solid transparent;
  border-bottom: 4px solid transparent;
  border-left: 7px solid #bbb;
}

.checkbox-icon.size-8.icon-preview.on {
  border-left-color: #62d2ff;
}

.checkbox-icon.size-8.icon-preview.on.write {
  border-left-color: #ff6268;
}

.checkbox-icon.size-8.icon-get {
   width: 0;
   height: 0;
   border-left: 4px solid transparent;
   border-right: 4px solid transparent;
   border-top: 8px solid #888;
}


.checkbox-icon.size-img16.icon-adsense {
   background: url(images/icons.png) -96px -80px;
   background-size: 160px 112px;
}

.checkbox-icon.size-img16.icon-tracking {
   background: url(images/icons.png) -32px -16px;
   background-size: 160px 112px;
}

.checkbox-icon.size-img16.icon-tracking.on {
   background: url(images/icons.png) -32px 0;
   background-size: 160px 112px;
}

.tracking-disabled .checkbox-icon.size-img16.icon-tracking.on {
   background: url(images/icons.png) -32px -32px;
   background-size: 160px 112px;
}

.checkbox-icon.size-img16.icon-php {
  background: url('images/icons.png') 0 -16px;
  background-size: 160px 112px;
}

.checkbox-icon.size-img16.icon-php.on {
  background: url('images/icons.png') 0 0;
  background-size: 160px 112px;
}



.ai-button .ui-button-text.ai-button-active, .ai-button .ui-button-text.ai-button-updating {
   background: #f44;
   border: 1px solid #f44;
   border-radius: 8px;
   width: 5px;
   height: 5px;
   padding: 0;
   margin: 1px 0px 1px 3px;
}

.filter-button .ui-button-text {
  padding: 0.1em 0.4em;
}

.ui-button-text.on {
  color: #f00;
}

.ai-page-code {
   margin: 0;
   padding: 5px;
   background: #eee;
   color: #00e;
   line-height: 15px;
}

pre.ai-wrap {
   white-space: pre-wrap;       /* Since CSS 2.1 */
   white-space: -moz-pre-wrap;  /* Mozilla, since 1999 */
   white-space: -pre-wrap;      /* Opera 4-6 */
   white-space: -o-pre-wrap;    /* Opera 7 */
   word-wrap: break-word;       /* Internet Explorer 5.5+ */
}

#ai-page-php {
   color: #0a0;
}

.ai-page-code-disabled, .ai-page-code-disabled #ai-page-php, .ai-page-code-disabled #ai-page-php.ai-page-code-disabled {
   color: #aaa;
}

#ai-page-php.ai-page-code-disabled {
   color: #00e;
}


.ai-weekdays {
  float: right;
}

.ai-weekdays ul.weekdays-list {
  margin: 0;
}

.ai-weekdays .weekdays-list .weekdays-day {
  padding: 4px 10px 3px;
  margin-bottom: 0;
  color: #888;
  font-weight: 700;
}

.ai-weekdays .weekdays-day:hover {
  color: #888;
}

.ai-weekdays .weekdays-list .weekday-selected {
  color: #007bff;
}

.ai-weekdays .weekdays-list :first-child {
  border-top-left-radius: 4px;
  border-bottom-left-radius: 4px;
}

.ai-weekdays .weekdays-list :last-child {
  border-top-right-radius: 4px;
  border-bottom-right-radius: 4px;
}


.banner-preview {
  float: left;
  margin: 0 10px 0 0;
}

.banner-preview img {
  max-width: 100px;
  max-height: 160px;
}

.ai-banner-top .banner-preview img {
  max-width: 718px;
  max-height: 100px;
}

.ai-banner-top table {
  float: right;
}

button.ai-notice-dismiss a {
  color: #fff;
}

#ai-sidebar .notice-dismiss {
  position: absolute;
  top: 0;
  right: 1px;
  border: none;
  margin: 0;
  padding: 9px;
  background: 0 0;
  color: #72777c;
  cursor: pointer;
}

#ai-sidebar .notice-dismiss:focus {
    outline: 0;
     -webkit-box-shadow: none;
    box-shadow: none;
}

#ai-sidebar .notice-dismiss.ui-state-active, #ai-sidebar .notice-dismiss.ui-widget-content .ui-state-active, #ai-sidebar .notice-dismiss.ui-widget-header .ui-state-active {
  background: 0 0!important;
}

.ai-form .ai-dot {
 font-size: 18px!important;
 line-height: 16px;
}

.ad-size .scombobox {
   width: 80px;
   display: inline-block;
   margin: 1px 0;
}

.scombobox-list p:hover, .scombobox-list p.scombobox-hovered {
   background-color: #eaeaea;
}

.scombobox-list p {
  padding: 1px;
}

.scombobox-display {
  padding-right: 1px;
}

table.check-pages a {
  display: none;
}

table.check-pages a span.dashicons {
  font-size: 16px;
  width: 16px;
  height: 16px;
}

#ai-sidebar-right {
  float: right;
}

.ai-image-left img, .ai-image-right img {
  margin-top: 10px;
}

.filter-type-select {
  max-width: 300px;
}

.desktop-only {
  display: none;
}

@media (max-width: 762px) {
   #ai-sidebar-right {
     float: none;
   }

   .ai-image-left {
     float: left;
     width: 49%;
   }

   .ai-image-right {
     float: right;
     width: 49%;
   }

   .ai-image-left img, .ai-image-right img {
     width: 100%;
     height: auto;
   }
}

@media (max-width: 782px) {
  #ai-settings {
    margin-right: 4px;
  }

  .auto-fold #wpcontent {
      padding-left: 4px;
  }
  #wpwrap {
    width: 762px;
  }

   .ai-toolbar-button.small {
     width: 20px;
     height: 20px;
     margin-right: 10px;
   }

   .ai-toolbar-button.small .checkbox-icon {
     margin: 4px 0px 0 4px;
   }

   .checkbox-icon.size-16 {
     width: 20px;
     height: 20px;
   }

   .ai-toolbar-button.small .checkbox-icon.size-img16 {
     margin: 0;
   }

   .ai-toolbar-button.small .checkbox-icon.size-img16.size-img16a {
     margin: 5px 4px 3px 4px;
   }

   .checkbox-icon.size-img16 {
/*     width: 24px;*/
/*     height:24px;*/
     background-size: 24px 24px;
   }

   .checkbox-icon.size-16w {
     width: 20px;
     height: 20px;
   }

   .list-button.lb-size-16 {
     margin: 6px 0 0 4px;
     padding: 0px 4px 2px 0px;
   }

   .ad-size .scombobox {
      width: 100px;
   }

   .scombobox-list p {
     font-size: 16px;
   }

   .filter-type-select {
     max-width: 258px;
   }
}

@media(max-width: 768px) {
   .text .checkbox-button {
     padding: 2px 5px 2px 4px;
   }
   .ai-settings-table tr {
     height: 40px;
   }
   .ai-settings-table input[type=text] {
     height: 30px;
   }
   .ui-widget input, .ui-widget select, .ui-widget textarea, .ui-widget button {
      font-family: sans-serif,Arial,Verdana;
      font-size: 16px;
   }
   div.custom-range-controls {
     width: 720px;
   }
   input.ai-date-input {
     width: 90px;
     padding: 3px 3px;
   }
   .ai-form .ai-dot {
     font-size: 12px!important;
     line-height: 18px;
   }

   .banner-preview img {
     max-width: 160px;
     max-height: 160px;
   }

   .ai-settings-table.left {
     width: 60%
   }

   .ai-settings-table.right {
     width: 40%
   }

   .ai-weekdays .weekdays-list .weekdays-day {
     padding: 12px 12px 11px;
   }
}

@media(min-width: 769px) {
   #ai-form select {
     line-height: 22px;
     height: 22px;
   }

   table.check-pages td.ai-position, table.check-pages td.ai-not-checked {
     font-size: 1.5em!important;
   }

   .desktop-only {
     display: block;
   }
}

@media (min-width: 783px) and (max-width: 828px) {
  .auto-fold #wpcontent, .auto-fold #wpfooter {
    margin-left: 20px;
  }
}

@media screen and (max-width: 782px){
  #wpbody .small-select select {
    height: 32px;
    font-size: 14px;
  }

  #wpbody span.small-input-tags {
    width: 22%;
  }
}


/* Fix for some themes */
#ai-settings select {
  padding: 2px 24px 2px 5px !important;
  min-height: 26px;
}

input[type=color], input[type=date], input[type=datetime-local], input[type=datetime], input[type=email],
input[type=month], input[type=number], input[type=password], input[type=search], input[type=tel],
input[type=text], input[type=time], input[type=url], input[type=week], .ui-widget select, textarea {
  border: 1px solid #ddd;
  min-height: 26px;
}

#ai-tooltip {
  position: absolute;
  z-index: 30000;
  max-width: 300px;
  text-align: justify;
  padding: 4px;
  font-family: arial;
  font-size: 11px;
  color: #FFF!important;
  border: 1px solid #c6c6c6;
  background: #ddd url(images/ui-bg_highlight-soft_50_dddddd_1x100.png) 50% 50% repeat-x;
  border-radius: 5px;
  -webkit-user-select: none;  /* Chrome all / Safari all */
  -moz-user-select: none;     /* Firefox all */
  -ms-user-select: none;      /* IE 10+ */
  user-select: none;
}

#ai-tooltip div {
  margin: 0;
  padding: 5px;
  background: #606060;
}

#ai-tooltip h3 {
  font-size: 11px;
  font-weight: bold;
  padding: 5px;
  margin: 0;
  color: #fff;
  background: #444;
  text-shadow: #000 1px 1px 0;
}

#ai-tooltip a {
  color: transparent;
  text-decoration: none;
  box-shadow: 0 0 0;
}

#ai-tooltip .tooltip-code {
  color: #5f5;
}

#ai-tooltip .tooltip-icon {
  color: #9cf;
}

table.check-pages {
  width: 100%;
  -webkit-user-select: none;  /* Chrome all / Safari all */
  -moz-user-select: none;     /* Firefox all */
  -ms-user-select: none;      /* IE 10+ */
  user-select: none;
  cursor: default;
}

table.check-pages th {
  font-weight: bold;
  text-align: center;
/*  white-space: nowrap;*/
}

table.check-pages td {
  text-align: center;
  vertical-align: top;
  line-height: 16px;
}

table.check-pages td.ai-position-name {
  height: 18px;
  vertical-align: middle;
}

table.check-pages td.ai-not-checked {
  color: #ababab;
}

table.check-pages td.ai-yes {
  color: #0b0;
}

table.check-pages td.ai-no {
  color: transparent;
}

table.ai-page-types {
  width: 100%;
}

table.ai-page-types td.ai-page-type.ai-unavailable input {
  background: #eee;
}

table.ai-page-types td.ai-page-type.ai-unavailable label {
  color: #bbb;
}

#ads-txt-table td {
  font-family: monospace, Courier, 'Courier New';
}

#ai-list-table tr.odd {
  background: #fff;
}

#ai-list-table td.ai-block-option.odd {
  background: #fff;
}

#ai-list-table tr.even {
  background: #eee;
}

#ai-list-table td.ai-block-option.even {
  background: #f8f8f8;
}

#ai-list-table tr.odd.ai-block-active {
  background: #efe;
}

#ai-list-table tr.ai-block-active td.ai-block-option.odd {
  background: #e8ffe8;
}

#ai-list-table tr.even.ai-block-active {
  background: #ded;
}

#ai-list-table tr.ai-block-active td.ai-block-option.even {
  background: #e8f8e8;
}

#ai-list-table tr.ai-block-active td.ai-block-option.even {
  background: #e8f8e8;
}

.checkbox-button.report-button {
  background: transparent;
  width: 12px;
  height: 14px;
  line-height: 15px;
  font-size: 16px;
  padding: 1px 0 0 0;
  border: 0;
  color: #333333;
}

.checkbox-button.report-button.on {
  color: #43e500;
}

.checkbox-button.report-button.off {
  color: #666  ;
}

.checkbox-button.report-button.add-option {
  color: #42c0fb80;
}

.checkbox-button.report-button.add {
  color: #42c0fbc0;
}

#ai-reports-table {
 width: 100%;
 line-height: 16px;
}

#ai-reports-table tr.report-name td {
 line-height: 28px;
 font-size: 16px !important;
 font-weight: 700;
}

#ai-reports-table tr.report-name td:empty::after {
  content:"\00a0";
}

#ai-reports-table tr.odd {
  background: #fff;
}

#ai-reports-table tr.even {
  background: #eee;
}

#ai-reports-table tr.selected {
  background: #e3f7ff;
}

#ai-reports-table td.report-status {
  width: 15px;
  padding-left: 20px;
}

