<?php
// phpcs:disable Yoast.NamingConventions.NamespaceName.TooLong -- Needed in the folder structure.
// phpcs:disable Yoast.NamingConventions.NamespaceName.MaxExceeded
namespace Yoast\WP\SEO\AI\Consent\Infrastructure\Endpoints;

use Yoast\WP\SEO\Routes\Endpoint\Endpoint_Interface;

interface Consent_Endpoint_Interface extends Endpoint_Interface {}
