(()=>{var e={7667(e){var t,n,o="",r=function(e){e=e||"polite";var t=document.createElement("div");return t.id="a11y-speak-"+e,t.className="a11y-speak-region",t.setAttribute("style","clip: rect(1px, 1px, 1px, 1px); position: absolute; height: 1px; width: 1px; overflow: hidden; word-wrap: normal;"),t.setAttribute("aria-live",e),t.setAttribute("aria-relevant","additions text"),t.setAttribute("aria-atomic","true"),document.querySelector("body").appendChild(t),t};!function(e){if("complete"===document.readyState||"loading"!==document.readyState&&!document.documentElement.doScroll)return e();document.addEventListener("DOMContentLoaded",e)}(function(){t=document.getElementById("a11y-speak-polite"),n=document.getElementById("a11y-speak-assertive"),null===t&&(t=r("polite")),null===n&&(n=r("assertive"))}),e.exports=function(e,r){!function(){for(var e=document.querySelectorAll(".a11y-speak-region"),t=0;t<e.length;t++)e[t].textContent=""}(),e=e.replace(/<[^<>]+>/g," "),o===e&&(e+=" "),o=e,n&&"assertive"===r?n.textContent=e:t&&(t.textContent=e)}}},t={};function n(o){var r=t[o];if(void 0!==r)return r.exports;var s=t[o]={exports:{}};return e[o](s,s.exports,n),s.exports}n.n=e=>{var t=e&&e.__esModule?()=>e.default:()=>e;return n.d(t,{a:t}),t},n.d=(e,t)=>{for(var o in t)n.o(t,o)&&!n.o(e,o)&&Object.defineProperty(e,o,{enumerable:!0,get:t[o]})},n.o=(e,t)=>Object.prototype.hasOwnProperty.call(e,t),(()=>{"use strict";const e=window.jQuery;var t=n.n(e),o=n(7667),r=n.n(o);const s=yoastReindexLinksData.data;let a=!1;class i{constructor(e){this.element=t()("#wpseo_count_index_links"),this.progressbarTarget=t()("#wpseo_index_links_progressbar").progressbar({value:0}),this.total=parseInt(e,10),this.totalProcessed=0}update(e){this.totalProcessed+=e;const t=this.totalProcessed*(100/this.total);this.progressbarTarget.progressbar("value",Math.round(t)),this.element.html(this.totalProcessed)}complete(){this.progressbarTarget.progressbar("value",100)}}function l(e,n){t().ajax({type:"GET",url:s.restApi.root+s.restApi.endpoint,beforeSend:e=>{e.setRequestHeader("X-WP-Nonce",s.restApi.nonce)},success:t=>{const o=parseInt(t,10);if(0!==o)return e.update(o),void l(e,n);e.complete(),n()}})}function c(){return new Promise(e=>{l(new i(s.amount),e)})}function d(){a=!0,r()(s.l10n.calculationCompleted),t()("#reindexLinks").html(s.message.indexingCompleted),tb_remove()}function u(){t()("#general-tab").trigger("click"),!1===a&&t()("#openLinkIndexing").trigger("click")}t()(function(){let e=!1;t()(".yoast-js-calculate-index-links--all ").on("click",function(){!1===e&&(function(){r()(s.l10n.calculationInProgress);const e=[];e.push(c()),Promise.all(e).then(d)}(),e=!0)}),t()("#noticeRunLinkIndex").on("click",u),-1!==window.location.href.indexOf("&reIndexLinks=1")&&t()(u)})})()})();