<?php

namespace Yoast\WP\SEO\Integrations\Alerts;

/**
 * Black_Friday_Promo_Notification class.
 */
class Black_Friday_Sidebar_Checklist_Notification extends Abstract_Dismissable_Alert {

	/**
	 * Holds the alert identifier.
	 *
	 * @var string
	 */
	protected $alert_identifier = 'black-friday-2023-sidebar-checklist';
}
