<?php

defined("ABSPATH") || exit;

/**
 * Variables
 *
 * @var \Duplicator\Core\Views\TplMng $tplMng
 * @var array<string, mixed> $tplData
 */
?>
<p>
    <?php
    printf(
        __(
            'Elevate your backup capabilities with advanced permissions, allowing for precise control over the creation, ' .
            'exportation, restoration, and management of control settings. Enjoy granular access control to ensure only ' .
            'authorized users can perform these critical functions.',
            'duplicator'
        )
    );
    ?>
</p>
