(()=>{"use strict";var e,s={};e=s,Object.defineProperty(e,"__esModule",{value:!0}),e.isFeatureEnabled=e.enabledFeatures=e.enableFeatures=void 0,e.isFeatureEnabled=function(e){return!!self.wpseoFeatureFlags&&self.wpseoFeatureFlags.includes(e)},e.enableFeatures=function(e){self.wpseoFeatureFlags||(self.wpseoFeatureFlags=[]),e.forEach(e=>{self.wpseoFeatureFlags.includes(e)||self.wpseoFeatureFlags.push(e)})},e.enabledFeatures=function(){return self.wpseoFeatureFlags||[]},(window.yoast=window.yoast||{}).featureFlag=s})();