<?php

use Duplicator\Installer\Utils\InstallerLinkManager;

defined('ABSPATH') || defined('DUPXABSPATH') || exit;

?>
<div id="addtional-help-content">
    For additional help please visit
    <a href="<?php echo InstallerLinkManager::getDocUrl('', 'install', 'additional help'); ?>" target="_blank">
        Duplicator Migration and Backup Online Help
    </a>
</div>
