/*!
 * jQuery UI Spinner @VERSION
 * http://jqueryui.com
 *
 * Copyright 2013 jQuery Foundation and other contributors
 * Released under the MIT license.
 * http://jquery.org/license
 *
 * http://api.jqueryui.com/spinner/#theming
 */
.ui-spinner {
	position: relative;
	display: inline-block;
	overflow: hidden;
	padding: 0;
	vertical-align: middle;
}
.ui-spinner-input {
	border: none;
	background: none;
	color: inherit;
	padding: 0;
	margin: .2em 0;
	vertical-align: middle;
	margin-left: .4em;
	margin-right: 22px;
}
.ui-spinner-right .ui-spinner-input {
	margin: .2em 0;
	margin-left: .4em;
	margin-right: 22px;
}
.ui-spinner-left .ui-spinner-input { 
	margin: .2em 0;
	margin-right: .4em;
	margin-left: 22px;
	text-align: right;
}
.ui-spinner-vertical .ui-spinner-input {
	margin: 0 .2em;
	margin-top: 12px;
	margin-bottom: 12px;
	text-align: center;
}
.ui-spinner-horizontal .ui-spinner-input {
	margin: .2em 0;
	margin-left: 12px;
	margin-right: 12px;
	text-align: center;
}
.ui-spinner-button {
	font-size: .5em;
	padding: 0;
	margin: 0;
	text-align: center;
	position: absolute;
	cursor: default;
	display: block;
	overflow: hidden;
}
.ui-spinner-right .ui-spinner-button {
	width: 16px;
	height: 50%;
	right: 0;
}
.ui-spinner-left .ui-spinner-button {
	width: 16px;
	height: 50%;
	left: 0;
}
.ui-spinner-vertical .ui-spinner-button {
	width: 100%;
	height: 10px;
	left: 0;
}
.ui-spinner-horizontal .ui-spinner-button {
	width: 10px;
	height: 100%;
	top: 0;
}
/* more specificity required here to overide default borders */
.ui-spinner a.ui-spinner-button {
	border: none;
}
.ui-spinner .ui-icon {
	position: absolute;
}
/* vertical centre icon */
.ui-spinner-right .ui-icon {
	margin-top: -8px;
	top: 50%;
	left: 0;
}
/* vertical centre icon */
.ui-spinner-left .ui-icon {
	margin-top: -8px;
	top: 50%;
	left: 0;
}
.ui-spinner-vertical .ui-icon {
	margin-top: -3px;
	margin-left: -7px;
	top: 0;
	left: 50%;
}
.ui-spinner-horizontal .ui-icon {
	margin-top: -8.5px;
	margin-left: -3px;
	top: 50%;
	left: 0;
}
.ui-spinner-up {
	top: 0;
}
.ui-spinner-down {
	bottom: 0;
}
.ui-spinner-horizontal .ui-spinner-up {
	right: 0;
}
.ui-spinner-horizontal .ui-spinner-down {
	left: 0;
}
/* TR overrides */
.ui-spinner .ui-icon-triangle-1-s {
   /* need to fix icons sprite */
   background-position: -65px -16px;
}
