.seo_page_wpseo_page_bulk_edit{--tw-bg-opacity:1;background-color:rgb(241 245 249/var(--tw-bg-opacity,1))}.seo_page_wpseo_page_bulk_edit #wpcontent{padding-right:0!important}@media (min-width:601px) and (max-width:768px){.seo_page_wpseo_page_bulk_edit .yst-mobile-navigation__top{top:46px}}@media (min-width:783px){.seo_page_wpseo_page_bulk_edit .yst-mobile-navigation__top{display:none}}.seo_page_wpseo_page_bulk_edit .yst-root .yst-mobile-navigation__dialog{z-index:99999}@media (min-width:640px){.seo_page_wpseo_page_bulk_edit .sm\:yst-block{display:block!important}.seo_page_wpseo_page_bulk_edit .sm\:yst-flex-row{flex-direction:row!important}.seo_page_wpseo_page_bulk_edit .sm\:yst-table-fixed{table-layout:fixed!important}.seo_page_wpseo_page_bulk_edit .sm\:yst-w-80{width:20rem!important}}@media (min-width:783px){.seo_page_wpseo_page_bulk_edit .min-\[783px\]\:yst-block{display:block!important}.seo_page_wpseo_page_bulk_edit .min-\[783px\]\:yst-p-8{padding:2rem!important}}.yst-root .yst-bulk-editor-ai-suggestion{background-image:linear-gradient(to bottom left,#cd82ab,#a3b3ff);padding:1px}.yst-root .yst-bulk-editor-ai-suggestion textarea.yst-textarea{--tw-bg-opacity:1!important;background-color:rgb(250 243 247/var(--tw-bg-opacity,1))!important}.yst-root .yst-bulk-editor-error-dismiss{font-size:10px}.yst-root .yst-bulk-editor-error-body{max-width:576px}.yst-root .yst-bulk-editor-cell-value{overflow-wrap:break-word}.yst-root .yst-bulk-editor-title-link,.yst-root .yst-bulk-editor-title-link:visited{position:relative;width:fit-content;--tw-text-opacity:1;color:rgb(30 41 59/var(--tw-text-opacity,1));text-decoration-line:none}.yst-root .yst-bulk-editor-title-link:after{bottom:0;content:"";height:1px;inset-inline-start:0;position:absolute;width:100%;--tw-bg-opacity:1;background-color:rgb(30 41 59/var(--tw-bg-opacity,1));opacity:0;transition-duration:.3s;transition-property:opacity;transition-timing-function:cubic-bezier(.4,0,.2,1)}.yst-root .yst-bulk-editor-title-link:focus-visible,.yst-root .yst-bulk-editor-title-link:focus-visible:visited,.yst-root .yst-bulk-editor-title-link:hover,.yst-root .yst-bulk-editor-title-link:hover:visited{--tw-text-opacity:1;color:rgb(15 23 42/var(--tw-text-opacity,1))}.yst-root .yst-bulk-editor-title-link:focus-visible:after,.yst-root .yst-bulk-editor-title-link:hover:after{--tw-bg-opacity:1;background-color:rgb(15 23 42/var(--tw-bg-opacity,1));opacity:1}.yst-root .yst-bulk-editor-title-link:focus:not(:focus-visible){outline:2px solid transparent;outline-offset:2px}