(()=>{var e={7667(e){var t,n,a="",r=function(e){e=e||"polite";var t=document.createElement("div");return t.id="a11y-speak-"+e,t.className="a11y-speak-region",t.setAttribute("style","clip: rect(1px, 1px, 1px, 1px); position: absolute; height: 1px; width: 1px; overflow: hidden; word-wrap: normal;"),t.setAttribute("aria-live",e),t.setAttribute("aria-relevant","additions text"),t.setAttribute("aria-atomic","true"),document.querySelector("body").appendChild(t),t};!function(e){if("complete"===document.readyState||"loading"!==document.readyState&&!document.documentElement.doScroll)return e();document.addEventListener("DOMContentLoaded",e)}(function(){t=document.getElementById("a11y-speak-polite"),n=document.getElementById("a11y-speak-assertive"),null===t&&(t=r("polite")),null===n&&(n=r("assertive"))}),e.exports=function(e,r){!function(){for(var e=document.querySelectorAll(".a11y-speak-region"),t=0;t<e.length;t++)e[t].textContent=""}(),e=e.replace(/<[^<>]+>/g," "),a===e&&(e+=" "),a=e,n&&"assertive"===r?n.textContent=e:t&&(t.textContent=e)}}},t={};function n(a){var r=t[a];if(void 0!==r)return r.exports;var o=t[a]={exports:{}};return e[a](o,o.exports,n),o.exports}n.n=e=>{var t=e&&e.__esModule?()=>e.default:()=>e;return n.d(t,{a:t}),t},n.d=(e,t)=>{for(var a in t)n.o(t,a)&&!n.o(e,a)&&Object.defineProperty(e,a,{enumerable:!0,get:t[a]})},n.o=(e,t)=>Object.prototype.hasOwnProperty.call(e,t),(()=>{"use strict";var e=n(7667),t=n.n(e);const a=window.jQuery;!function(e){function n(n){var a,r,o=e(".wrap > h1");n.length&&(a=n.map(function(e){return"<div class='"+e.type+" notice'><p>"+e.message+"</p></div>"}),o.after(a.join("")),r=wpseoNetworkAdminGlobalL10n.error_prefix,"updated"===n[0].type&&(r=wpseoNetworkAdminGlobalL10n.success_prefix),t()(r.replace("%s",n[0].message),"assertive"))}function a(t){var a=e(this),r=a.find("[type='submit']:focus"),o=a.serialize();return t.preventDefault(),e(".wrap > .notice").remove(),r.length||(r=e(".wpseotab.active [type='submit']")),"action"===r.attr("name")&&(o=o.replace(/action=([a-zA-Z0-9_]+)/,"action="+r.val())),e.ajax({type:"POST",url:ajaxurl,data:o}).done(function(e){e.data&&n(e.data)}).fail(function(e){var t=e.responseJSON;t&&t.data&&n(t.data)}),!1}e(document).ready(function(){var t=e("#wpseo-conf");t.length&&t.on("submit",a)})}(n.n(a)())})()})();